@@ -35,11 +35,6 @@ static GdkPixbuf * new_separator_pixbuf         (void);
 #define EGG_ITEM_NAME      "egg-item-name"
 #define STOCK_DRAG_MODE    "stock_drag-mode"
 
-#if GTK_CHECK_VERSION (3, 2, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 static const GtkTargetEntry dest_drag_types[] = {
   {EGG_TOOLBAR_ITEM_TYPE, GTK_TARGET_SAME_APP, 0},
 };
@@ -86,11 +81,7 @@ struct _EggEditableToolbarPrivate
   GtkToolItem *dnd_toolitem;
 };
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 G_DEFINE_TYPE (EggEditableToolbar, egg_editable_toolbar, GTK_TYPE_BOX)
-#else
-G_DEFINE_TYPE (EggEditableToolbar, egg_editable_toolbar, GTK_TYPE_VBOX);
-#endif
 
 static int
 get_dock_position (EggEditableToolbar *etoolbar,
@@ -300,7 +291,13 @@ move_item_cb (GtkAction          *action,
   gdk_event_get_coords (realevent, &event.x, &event.y);
   gdk_event_get_root_coords (realevent, &event.x_root, &event.y_root);
 
-  gtk_drag_begin (toolitem, list, GDK_ACTION_MOVE, 1, (GdkEvent *)&event);
+  gtk_drag_begin_with_coordinates (toolitem,
+                                   list,
+                                   GDK_ACTION_MOVE,
+                                   1,
+                                   (GdkEvent *)&event,
+                                   event.x,
+                                   event.y);
   gtk_target_list_unref (list);
 }
 
@@ -361,7 +358,7 @@ popup_context_menu_cb (GtkWidget          *toolbar,
       menu = GTK_MENU (gtk_ui_manager_get_widget (etoolbar->priv->manager,
 						  etoolbar->priv->popup_path));
       g_return_if_fail (menu != NULL);
-      gtk_menu_popup (menu, NULL, NULL, NULL, NULL, button_number, gtk_get_current_event_time ());
+      gtk_menu_popup_at_pointer (menu, NULL);
       g_signal_connect_object (menu, "selection-done",
 			       G_CALLBACK (popup_context_deactivate),
 			       etoolbar, 0);
@@ -383,7 +380,7 @@ button_press_event_cb (GtkWidget *widget,
       menu = GTK_MENU (gtk_ui_manager_get_widget (etoolbar->priv->manager,
 						  etoolbar->priv->popup_path));
       g_return_val_if_fail (menu != NULL, FALSE);
-      gtk_menu_popup (menu, NULL, NULL, NULL, NULL, event->button, event->time);
+      gtk_menu_popup_at_pointer (menu, (const GdkEvent*) event);
       g_signal_connect_object (menu, "selection-done",
 			       G_CALLBACK (popup_context_deactivate),
 			       etoolbar, 0);
@@ -434,11 +431,7 @@ configure_item_cursor (GtkToolItem *item,
           cursor = gdk_cursor_new_for_display (gdk_screen_get_display (screen),
 					       GDK_HAND2);
           gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
-#if GTK_CHECK_VERSION (3, 0, 0)
           g_object_unref (cursor);
-#else
-          gdk_cursor_unref (cursor);
-#endif
 
           gtk_drag_source_set (widget, GDK_BUTTON1_MASK, dest_drag_types,
                                G_N_ELEMENTS (dest_drag_types), GDK_ACTION_MOVE);
@@ -467,24 +460,13 @@ configure_item_cursor (GtkToolItem *item,
                 {
                   GdkScreen *screen;
                   GtkIconTheme *icon_theme;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-                  GtkSettings *settings;
-#endif
                   gint width, height;
 
                   screen = gtk_widget_get_screen (widget);
                   icon_theme = gtk_icon_theme_get_for_screen (screen);
-#if GTK_CHECK_VERSION (3, 0, 0)
 
                   if (!gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR,
                                              &width, &height))
-#else
-                  settings = gtk_settings_get_for_screen (screen);
-
-                  if (!gtk_icon_size_lookup_for_settings (settings,
-                                                          GTK_ICON_SIZE_LARGE_TOOLBAR,
-                                                          &width, &height))
-#endif
                     {
                       width = height = 24;
                     }
@@ -997,7 +979,7 @@ create_dock (EggEditableToolbar *etoolbar)
 {
   GtkWidget *toolbar, *hbox;
 
-  hbox = gtk_hbox_new (0, FALSE);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
   toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), TRUE);
@@ -1347,10 +1329,8 @@ egg_editable_toolbar_set_model (EggEditableToolbar *etoolbar,
 static void
 egg_editable_toolbar_init (EggEditableToolbar *etoolbar)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
   gtk_orientable_set_orientation (GTK_ORIENTABLE (etoolbar),
                                   GTK_ORIENTATION_VERTICAL);
-#endif
 
   EggEditableToolbarPrivate *priv;
 
@@ -1415,9 +1395,9 @@ egg_editable_toolbar_set_ui_manager (EggEditableToolbar *etoolbar,
   static const GtkActionEntry actions[] = {
     { "MoveToolItem", STOCK_DRAG_MODE, N_("_Move on Toolbar"), NULL,
       N_("Move the selected item on the toolbar"), G_CALLBACK (move_item_cb) },
-    { "RemoveToolItem", GTK_STOCK_REMOVE, N_("_Remove from Toolbar"), NULL,
+    { "RemoveToolItem", "list-remove", N_("_Remove from Toolbar"), NULL,
       N_("Remove the selected item from the toolbar"), G_CALLBACK (remove_item_cb) },
-    { "RemoveToolbar", GTK_STOCK_DELETE, N_("_Delete Toolbar"), NULL,
+    { "RemoveToolbar", "edit-delete", N_("_Delete Toolbar"), NULL,
       N_("Remove the selected toolbar"), G_CALLBACK (remove_toolbar_cb) },
   };
 
@@ -1756,20 +1736,10 @@ new_pixbuf_from_widget (GtkWidget *widget)
   GtkWidget *window;
   GdkPixbuf *pixbuf;
   gint icon_height;
-  GdkScreen *screen;
 
-  screen = gtk_widget_get_screen (widget);
-
-#if GTK_CHECK_VERSION (3, 0, 0)
   if (!gtk_icon_size_lookup (GTK_ICON_SIZE_LARGE_TOOLBAR,
                              NULL,
                              &icon_height))
-#else
-  if (!gtk_icon_size_lookup_for_settings (gtk_settings_get_for_screen (screen),
-                                          GTK_ICON_SIZE_LARGE_TOOLBAR,
-                                          NULL,
-                                          &icon_height))
-#endif
     {
       icon_height = DEFAULT_ICON_HEIGHT;
     }
@@ -1794,11 +1764,7 @@ new_separator_pixbuf (void)
   GtkWidget *separator;
   GdkPixbuf *pixbuf;
 
-#if GTK_CHECK_VERSION(3, 0, 0)
   separator = gtk_separator_new (GTK_ORIENTATION_VERTICAL);
-#else
-  separator = gtk_vseparator_new ();
-#endif
   pixbuf = new_pixbuf_from_widget (separator);
   return pixbuf;
 }
