@@ -260,10 +260,8 @@ egg_toolbar_editor_class_init (EggToolbarEditorClass *klass)
 						       G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
 						       G_PARAM_CONSTRUCT));
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   GtkWidgetClass *widget_class  = GTK_WIDGET_CLASS (klass);
   gtk_widget_class_set_css_name (widget_class, "EggToolbarEditor");
-#endif
 
   g_type_class_add_private (object_class, sizeof (EggToolbarEditorPrivate));
 }
@@ -510,8 +508,8 @@ editor_create_item_from_name (EggToolbarEditor *editor,
         icon = gtk_image_new_from_icon_name (icon_name,
 	                                     GTK_ICON_SIZE_LARGE_TOOLBAR);
       else
-        icon = gtk_image_new_from_stock (stock_id ? stock_id : GTK_STOCK_DND,
-                                         GTK_ICON_SIZE_LARGE_TOOLBAR);
+        icon = gtk_image_new_from_icon_name (stock_id ? stock_id : "gtk-dnd",
+                                             GTK_ICON_SIZE_LARGE_TOOLBAR);
 
       item_name = g_strdup (name);
       collate_key = g_utf8_collate_key (short_label, -1);
@@ -537,29 +535,24 @@ append_grid (GtkGrid *grid, GList *items, gint y, gint width)
   if (items != NULL)
     {
       gint x = 0;
-      GtkWidget *alignment;
       GtkWidget *item;
 
       if (y > 0)
         {
           item = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
-          alignment = gtk_alignment_new (0.5, 0.5, 1.0, 0.0);
-          g_object_set (G_OBJECT (alignment), "expand", TRUE, NULL);
-          gtk_container_add (GTK_CONTAINER (alignment), item);
-          gtk_widget_show (alignment);
+          gtk_widget_set_hexpand (item, TRUE);
+          gtk_widget_set_vexpand (item, FALSE);
           gtk_widget_show (item);
 
-          gtk_grid_attach (grid, alignment, 0, y, width, 1);
+          gtk_grid_attach (grid, item, 0, y, width, 1);
           y++;
         }
 
       for (; items != NULL; items = items->next)
         {
           item = items->data;
-          alignment = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-          g_object_set (G_OBJECT (alignment), "expand", TRUE, NULL);
-          gtk_container_add (GTK_CONTAINER (alignment), item);
-          gtk_widget_show (alignment);
+          gtk_widget_set_hexpand (item, FALSE);
+          gtk_widget_set_vexpand (item, FALSE);
           gtk_widget_show (item);
 
           if (x >= width)
@@ -567,7 +560,7 @@ append_grid (GtkGrid *grid, GList *items, gint y, gint width)
               x = 0;
               y++;
             }
-          gtk_grid_attach (grid, alignment, x, y, 1, 1);
+          gtk_grid_attach (grid, item, x, y, 1, 1);
           x++;
         }
 
