@@ -67,18 +67,13 @@ struct _EomCloseConfirmationDialogPrivate
 	GtkCellRenderer *toggle_renderer;
 };
 
-
-#define EOM_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-							EOM_TYPE_CLOSE_CONFIRMATION_DIALOG, \
-							EomCloseConfirmationDialogPrivate))
-
 #define GET_MODE(priv) (((priv->unsaved_images != NULL) && \
 			 (priv->unsaved_images->next == NULL)) ? \
 			  SINGLE_IMG_MODE : MULTIPLE_IMGS_MODE)
 
 #define IMAGE_COLUMN_HEIGHT 40
 
-G_DEFINE_TYPE(EomCloseConfirmationDialog, eom_close_confirmation_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE (EomCloseConfirmationDialog, eom_close_confirmation_dialog, GTK_TYPE_DIALOG)
 
 static void 	 set_unsaved_image 		(EomCloseConfirmationDialog *dlg,
 						 const GList                  *list);
@@ -160,10 +155,10 @@ add_buttons (EomCloseConfirmationDialog *dlg)
 			       GTK_RESPONSE_NO);
 
 	gtk_dialog_add_button (GTK_DIALOG (dlg),
-			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+			       "gtk-cancel", GTK_RESPONSE_CANCEL);
 	
 	gtk_dialog_add_button (GTK_DIALOG (dlg),
-			       GTK_STOCK_SAVE,
+			       "gtk-save",
 			       GTK_RESPONSE_YES);
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (dlg), 
@@ -175,7 +170,7 @@ eom_close_confirmation_dialog_init (EomCloseConfirmationDialog *dlg)
 {
 	AtkObject *atk_obj;
 
-	dlg->priv = EOM_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE (dlg);
+	dlg->priv = eom_close_confirmation_dialog_get_instance_private (dlg);
 
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);		
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), 14);
@@ -267,8 +262,6 @@ eom_close_confirmation_dialog_class_init (EomCloseConfirmationDialogClass *klass
 	gobject_class->get_property = eom_close_confirmation_dialog_get_property;
 	gobject_class->finalize = eom_close_confirmation_dialog_finalize;
 
-	g_type_class_add_private (klass, sizeof (EomCloseConfirmationDialogPrivate));
-
 	g_object_class_install_property (gobject_class,
 					 PROP_UNSAVED_IMAGES,
 					 g_param_spec_pointer ("unsaved_images",
@@ -683,17 +676,3 @@ eom_close_confirmation_dialog_get_unsaved_images (EomCloseConfirmationDialog *dl
 	return dlg->priv->unsaved_images;
 }
 
-void
-eom_close_confirmation_dialog_set_sensitive (EomCloseConfirmationDialog *dlg,
-					     gboolean value)
-{
-	GtkWidget *action_area;
-
-	g_return_if_fail (EOM_IS_CLOSE_CONFIRMATION_DIALOG (dlg));
-
-	action_area = gtk_dialog_get_action_area (GTK_DIALOG (dlg));
-	gtk_widget_set_sensitive (action_area, value);
-
-	if (dlg->priv->toggle_renderer)
-		gtk_cell_renderer_toggle_set_activatable (GTK_CELL_RENDERER_TOGGLE (dlg->priv->toggle_renderer), value);
-}
