@@ -629,7 +629,36 @@ eom_image_apply_display_profile (EomImage *img, cmsHPROFILE screen)
 
 	priv = img->priv;
 
-	if (screen == NULL || priv->profile == NULL) return;
+	if (screen == NULL) return;
+
+	if (priv->profile == NULL) {
+		/* Check whether GdkPixbuf was able to extract a profile */
+		const char* data = gdk_pixbuf_get_option (priv->image,
+		                                          "icc-profile");
+
+		if(data) {
+			gsize   profile_size = 0;
+			guchar *profile_data = g_base64_decode(data,
+			                                       &profile_size);
+
+			if (profile_data && profile_size > 0) {
+				eom_debug_message (DEBUG_LCMS,
+				                   "Using ICC profile "
+				                   "extracted by GdkPixbuf");
+				priv->profile =
+					cmsOpenProfileFromMem(profile_data,
+					                      profile_size);
+				g_free(profile_data);
+			}
+		}
+
+		if(priv->profile == NULL) {
+			/* Assume sRGB color space for images without ICC profile */
+			eom_debug_message (DEBUG_LCMS, "Image has no ICC profile. "
+					   "Assuming sRGB.");
+			priv->profile = cmsCreate_sRGBProfile ();
+		}
+	}
 
 	/* TODO: support other colorspaces than RGB */
 	if (cmsGetColorSpace (priv->profile) != cmsSigRgbData ||
@@ -638,18 +667,17 @@ eom_image_apply_display_profile (EomImage *img, cmsHPROFILE screen)
 		return;
 	}
 
-	/* TODO: find the right way to colorcorrect RGBA images */
-	if (gdk_pixbuf_get_has_alpha (priv->image)) {
-		eom_debug_message (DEBUG_LCMS, "Colorcorrecting RGBA images is unsupported.");
-		return;
-	}
+	cmsUInt32Number color_type = TYPE_RGB_8;
+
+	if (gdk_pixbuf_get_has_alpha (priv->image))
+		color_type = TYPE_RGBA_8;
 
 	transform = cmsCreateTransform (priv->profile,
-				        TYPE_RGB_8,
-				        screen,
-				        TYPE_RGB_8,
-				        INTENT_PERCEPTUAL,
-				        0);
+	                                color_type,
+	                                screen,
+	                                color_type,
+	                                INTENT_PERCEPTUAL,
+	                                0);
 
 	if (G_LIKELY (transform != NULL)) {
 		rows = gdk_pixbuf_get_height (priv->image);
