@@ -26,11 +26,6 @@
 #include "eom-image.h"
 #include "eom-print-preview.h"
 
-#define EOM_PRINT_PREVIEW_GET_PRIVATE(object)				\
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_PRINT_PREVIEW, EomPrintPreviewPrivate))
-
-G_DEFINE_TYPE (EomPrintPreview, eom_print_preview, GTK_TYPE_ASPECT_FRAME)
-
 struct _EomPrintPreviewPrivate {
 	GtkWidget *area;
 	GdkPixbuf *image;
@@ -96,6 +91,8 @@ enum {
 	PROP_PAGE_BOTTOM_MARGIN
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (EomPrintPreview, eom_print_preview, GTK_TYPE_ASPECT_FRAME)
+
 static void eom_print_preview_draw (EomPrintPreview *preview, cairo_t *cr);
 static void eom_print_preview_finalize (GObject *object);
 static void update_relative_sizes (EomPrintPreview *preview);
@@ -389,8 +386,6 @@ eom_print_preview_class_init (EomPrintPreviewClass *klass)
 			      G_SIGNAL_RUN_FIRST, 0, NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
 			      0, NULL);
-
-	g_type_class_add_private (klass, sizeof (EomPrintPreviewPrivate));
 }
 
 static void
@@ -424,7 +419,7 @@ eom_print_preview_init (EomPrintPreview *preview)
 	EomPrintPreviewPrivate *priv;
 	gfloat ratio;
 
-	priv = preview->priv = EOM_PRINT_PREVIEW_GET_PRIVATE (preview);
+	priv = preview->priv = eom_print_preview_get_instance_private (preview);
 
 	priv->area = GTK_WIDGET (gtk_drawing_area_new ());
 
@@ -683,98 +678,6 @@ create_preview_buffer (EomPrintPreview *preview)
 	return pixbuf;
 }
 
-/*
-  Function inspired from gdk_cairo_set_source_pixbuf (). The main reason is
-  that I want to save the cairo_surface_t created from the scaled buffer to
-  improve performance.
-*/
-static cairo_surface_t *
-create_surface_from_pixbuf (GdkPixbuf *pixbuf)
-{
-  gint width = gdk_pixbuf_get_width (pixbuf);
-  gint height = gdk_pixbuf_get_height (pixbuf);
-  guchar *gdk_pixels = gdk_pixbuf_get_pixels (pixbuf);
-  int gdk_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-  int n_channels = gdk_pixbuf_get_n_channels (pixbuf);
-  int cairo_stride;
-  guchar *cairo_pixels;
-  cairo_format_t format;
-  cairo_surface_t *surface;
-  static const cairo_user_data_key_t key;
-  int j;
-
-  if (n_channels == 3)
-    format = CAIRO_FORMAT_RGB24;
-  else
-    format = CAIRO_FORMAT_ARGB32;
-
-  cairo_stride = cairo_format_stride_for_width (format, width);
-  cairo_pixels = g_malloc_n (height, cairo_stride);
-  surface = cairo_image_surface_create_for_data ((unsigned char *)cairo_pixels,
-						 format,
-						 width, height, cairo_stride);
-  cairo_surface_set_user_data (surface, &key,
-			       cairo_pixels, (cairo_destroy_func_t)g_free);
-
-  for (j = height; j; j--)
-    {
-      guchar *p = gdk_pixels;
-      guchar *q = cairo_pixels;
-
-      if (n_channels == 3)
-	{
-	  guchar *end = p + 3 * width;
-
-	  while (p < end)
-	    {
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN
-	      q[0] = p[2];
-	      q[1] = p[1];
-	      q[2] = p[0];
-#else
-	      q[1] = p[0];
-	      q[2] = p[1];
-	      q[3] = p[2];
-#endif
-	      p += 3;
-	      q += 4;
-	    }
-	}
-      else
-	{
-	  guchar *end = p + 4 * width;
-	  guint t1,t2,t3;
-
-#define MULT(d,c,a,t) G_STMT_START { t = c * a + 0x7f; d = ((t >> 8) + t) >> 8; } G_STMT_END
-
-	  while (p < end)
-	    {
-#if G_BYTE_ORDER == G_LITTLE_ENDIAN
-	      MULT(q[0], p[2], p[3], t1);
-	      MULT(q[1], p[1], p[3], t2);
-	      MULT(q[2], p[0], p[3], t3);
-	      q[3] = p[3];
-#else
-	      q[0] = p[3];
-	      MULT(q[1], p[0], p[3], t1);
-	      MULT(q[2], p[1], p[3], t2);
-	      MULT(q[3], p[2], p[3], t3);
-#endif
-
-	      p += 4;
-	      q += 4;
-	    }
-
-#undef MULT
-	}
-
-      gdk_pixels += gdk_rowstride;
-      cairo_pixels += cairo_stride;
-    }
-
-  return surface;
-}
-
 static void
 create_surface (EomPrintPreview *preview)
 {
@@ -788,7 +691,9 @@ create_surface (EomPrintPreview *preview)
 
 	pixbuf = create_preview_buffer (preview);
 	if (pixbuf) {
-		priv->surface = create_surface_from_pixbuf (pixbuf);
+		priv->surface =
+			gdk_cairo_surface_create_from_pixbuf (pixbuf, 0,
+			                                      gtk_widget_get_window (GTK_WIDGET (preview)));
 		g_object_unref (pixbuf);
 	}
 	priv->flag_create_surface = FALSE;
@@ -982,7 +887,6 @@ eom_print_preview_draw (EomPrintPreview *preview, cairo_t *cr)
 	GtkWidget *area;
 	GtkAllocation allocation;
 	gint x0, y0;
-	GdkRGBA color;
 	gboolean has_focus;
 
 	priv = preview->priv;
@@ -993,14 +897,12 @@ eom_print_preview_draw (EomPrintPreview *preview, cairo_t *cr)
 	gtk_widget_get_allocation (area, &allocation);
 
 	/* draw the page */
-	gdk_rgba_parse (&color, "white");
-	gdk_cairo_set_source_rgba (cr, &color);
+	cairo_set_source_rgb (cr, 1., 1., 1.);
  	cairo_rectangle (cr, 0, 0, allocation.width, allocation.height);
  	cairo_fill (cr);
 
 	/* draw the page margins */
-	gdk_rgba_parse (&color, "black");
-	gdk_cairo_set_source_rgba (cr, &color);
+	cairo_set_source_rgb (cr, 0., 0., 0.);
 	cairo_set_line_width (cr, 0.1);
 	cairo_rectangle (cr,
 			 priv->l_rmargin, priv->t_rmargin,
