@@ -48,14 +48,9 @@
 #endif
 
 #if HAVE_METADATA
-#include "eom-exif-details.h"
+#include "eom-metadata-details.h"
 #endif
 
-#define EOM_PROPERTIES_DIALOG_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_PROPERTIES_DIALOG, EomPropertiesDialogPrivate))
-
-G_DEFINE_TYPE (EomPropertiesDialog, eom_properties_dialog, EOM_TYPE_DIALOG);
-
 enum {
         PROP_0,
         PROP_THUMBVIEW,
@@ -80,9 +75,8 @@ struct _EomPropertiesDialogPrivate {
 	GtkWidget      *height_label;
 	GtkWidget      *type_label;
 	GtkWidget      *bytes_label;
-	GtkWidget      *location_label;
-	GtkWidget      *created_label;
-	GtkWidget      *modified_label;
+	GtkWidget      *folder_button;
+	gchar          *folder_button_uri;
 #ifdef HAVE_EXIF
 	GtkWidget      *exif_aperture_label;
 	GtkWidget      *exif_exposure_label;
@@ -99,11 +93,14 @@ struct _EomPropertiesDialogPrivate {
 	GtkWidget      *xmp_keywords_label;
 	GtkWidget      *xmp_creator_label;
 	GtkWidget      *xmp_rights_label;
+#else
+	GtkWidget      *xmp_box;
+	GtkWidget      *xmp_box_label;
 #endif
 #if HAVE_METADATA
-	GtkWidget      *exif_box;
-	GtkWidget      *exif_details_expander;
-	GtkWidget      *exif_details;
+	GtkWidget      *metadata_box;
+	GtkWidget      *metadata_details_expander;
+	GtkWidget      *metadata_details;
 	GtkWidget      *metadata_details_box;
 	GtkWidget      *metadata_details_sw;
 #endif
@@ -111,13 +108,42 @@ struct _EomPropertiesDialogPrivate {
 	gboolean        netbook_mode;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (EomPropertiesDialog, eom_properties_dialog, GTK_TYPE_DIALOG);
+
+static void
+parent_file_display_name_query_info_cb (GObject *source_object,
+					GAsyncResult *res,
+					gpointer user_data)
+{
+	EomPropertiesDialog *prop_dlg = EOM_PROPERTIES_DIALOG (user_data);
+	GFile *parent_file = G_FILE (source_object);
+	GFileInfo *file_info;
+	gchar *display_name;
+
+
+	file_info = g_file_query_info_finish (parent_file, res, NULL);
+	if (file_info == NULL) {
+		display_name = g_file_get_basename (parent_file);
+	} else {
+		display_name = g_strdup (
+			g_file_info_get_display_name (file_info));
+		g_object_unref (file_info);
+	}
+	gtk_button_set_label (GTK_BUTTON (prop_dlg->priv->folder_button),
+			      display_name);
+	gtk_widget_set_sensitive (prop_dlg->priv->folder_button, TRUE);
+
+	g_free (display_name);
+	g_object_unref (prop_dlg);
+}
+
 static void
 pd_update_general_tab (EomPropertiesDialog *prop_dlg,
 		       EomImage            *image)
 {
-	gchar *bytes_str, *dir_str, *uri_str;
+	gchar *bytes_str, *dir_str_long;
 	gchar *width_str, *height_str;
-	GFile *file;
+	GFile *file, *parent_file;
 	GFileInfo *file_info;
 	const char *mime_str;
 	char *type_str;
@@ -165,105 +191,37 @@ pd_update_general_tab (EomPropertiesDialog *prop_dlg,
 
 	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->bytes_label), bytes_str);
 
-	uri_str = eom_image_get_uri_for_display (image);
-	dir_str = g_path_get_dirname (uri_str);
-	gtk_label_set_text (GTK_LABEL (prop_dlg->priv->location_label),
-			    dir_str);
+	parent_file = g_file_get_parent (file);
+	if (parent_file == NULL) {
+		/* file is root directory itself */
+		parent_file = g_object_ref (file);
+	}
+
+	gtk_widget_set_sensitive (prop_dlg->priv->folder_button, FALSE);
+	gtk_button_set_label (GTK_BUTTON (prop_dlg->priv->folder_button), NULL);
+
+	dir_str_long = g_file_get_path (parent_file);
+	gtk_widget_set_tooltip_text (GTK_WIDGET (prop_dlg->priv->folder_button),
+	                             dir_str_long);
+
+	g_free (prop_dlg->priv->folder_button_uri);
+	prop_dlg->priv->folder_button_uri = g_file_get_uri (parent_file);
+
+	g_file_query_info_async (parent_file,
+				 G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
+				 G_FILE_QUERY_INFO_NONE,
+				 G_PRIORITY_DEFAULT,
+				 NULL,
+				 parent_file_display_name_query_info_cb,
+				 g_object_ref (prop_dlg));
+
+	g_object_unref (parent_file);
 
 	g_free (type_str);
 	g_free (bytes_str);
-	g_free (dir_str);
-	g_free (uri_str);
+	g_free (dir_str_long);
 }
 
-#if HAVE_EXIF
-static void
-eom_exif_set_label (GtkWidget *w, ExifData *exif_data, gint tag_id)
-{
-	gchar exif_buffer[512];
-	const gchar *buf_ptr;
-	gchar *label_text = NULL;
-
-	if (exif_data) {
-		buf_ptr = eom_exif_data_get_value (exif_data, tag_id,
-						   exif_buffer, 512);
-
-		if (tag_id == EXIF_TAG_DATE_TIME_ORIGINAL && buf_ptr)
-			label_text = eom_exif_util_format_date (buf_ptr);
-		else
-			label_text = eom_util_make_valid_utf8 (buf_ptr);
-	}
-
-	gtk_label_set_text (GTK_LABEL (w), label_text);
-	g_free (label_text);
-}
-
-static void
-eom_exif_set_focal_length_label (GtkWidget *w, ExifData *exif_data)
-{
-	ExifEntry *entry = NULL, *entry35mm = NULL;
-	ExifByteOrder byte_order;
-	gfloat f_val = 0.0;
-	gchar *fl_text = NULL,*fl35_text = NULL;
-
-	/* If no ExifData is supplied the label will be
-	 * cleared later as fl35_text is NULL. */
-	if (exif_data != NULL) {
-		entry = exif_data_get_entry (exif_data, EXIF_TAG_FOCAL_LENGTH);
-		entry35mm = exif_data_get_entry (exif_data,
-					    EXIF_TAG_FOCAL_LENGTH_IN_35MM_FILM);
-		byte_order = exif_data_get_byte_order (exif_data);
-	}
-
-	if (entry && G_LIKELY (entry->format == EXIF_FORMAT_RATIONAL)) {
-		ExifRational value;
-
-		/* Decode value by hand as libexif is not necessarily returning
-		 * it in the format we want it to be.
-		 */
-		value = exif_get_rational (entry->data, byte_order);
-		/* Guard against div by zero */
-		if (G_LIKELY(value.denominator != 0))
-			f_val = (gfloat)value.numerator/
-				(gfloat)value.denominator;
-
-		/* TRANSLATORS: This is the actual focal length used when
-		   the image was taken.*/
-		fl_text = g_strdup_printf (_("%.1f (lens)"), f_val);
-
-	}
-	if (entry35mm && G_LIKELY (entry35mm->format == EXIF_FORMAT_SHORT)) {
-		ExifShort s_val;
-
-		s_val = exif_get_short (entry35mm->data, byte_order);
-
-		/* Print as float to get a similar look as above. */
-		/* TRANSLATORS: This is the equivalent focal length assuming
-		   a 35mm film camera. */
-		fl35_text = g_strdup_printf(_("%.1f (35mm film)"),(float)s_val);
-	}
-
-	if (fl_text) {
-		if (fl35_text) {
-			gchar *merged_txt;
-
-			merged_txt = g_strconcat (fl35_text,", ", fl_text, NULL);
-			gtk_label_set_text (GTK_LABEL (w), merged_txt);
-			g_free (merged_txt);
-		} else {
-			gtk_label_set_text (GTK_LABEL (w), fl_text);
-		}
-	} else {
-		/* This will also clear the label if no ExifData was supplied */
-		gtk_label_set_text (GTK_LABEL (w), fl35_text);
-	}
-
-	g_free (fl35_text);
-	g_free (fl_text);
-
-}
-#endif
-
 #if HAVE_EXEMPI
 static void
 eom_xmp_set_label (XmpPtr xmp,
@@ -353,8 +311,8 @@ pd_update_metadata_tab (EomPropertiesDialog *prop_dlg,
 			gtk_notebook_set_current_page (notebook, EOM_PROPERTIES_DIALOG_PAGE_GENERAL);
 		}
 
-		if (gtk_widget_get_visible (priv->exif_box)) {
-			gtk_widget_hide (priv->exif_box);
+		if (gtk_widget_get_visible (priv->metadata_box)) {
+			gtk_widget_hide (priv->metadata_box);
 		}
 		if (gtk_widget_get_visible (priv->metadata_details_box)) {
 			gtk_widget_hide (priv->metadata_details_box);
@@ -362,43 +320,43 @@ pd_update_metadata_tab (EomPropertiesDialog *prop_dlg,
 
 		return;
 	} else {
-		if (!gtk_widget_get_visible (priv->exif_box))
-			gtk_widget_show_all (priv->exif_box);
+		if (!gtk_widget_get_visible (priv->metadata_box))
+			gtk_widget_show_all (priv->metadata_box);
 		if (priv->netbook_mode &&
 		    !gtk_widget_get_visible (priv->metadata_details_box)) {
 			gtk_widget_show_all (priv->metadata_details_box);
-			gtk_widget_hide (priv->exif_details_expander);
+			gtk_widget_hide (priv->metadata_details_expander);
 		}
 	}
 
 #if HAVE_EXIF
 	exif_data = (ExifData *) eom_image_get_exif_info (image);
 
-	eom_exif_set_label (priv->exif_aperture_label,
-			    exif_data, EXIF_TAG_FNUMBER);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_aperture_label),
+				      exif_data, EXIF_TAG_FNUMBER);
 
-	eom_exif_set_label (priv->exif_exposure_label,
-			    exif_data, EXIF_TAG_EXPOSURE_TIME);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_exposure_label),
+				      exif_data, EXIF_TAG_EXPOSURE_TIME);
 
-	eom_exif_set_focal_length_label (priv->exif_focal_label, exif_data);
+	eom_exif_util_set_focal_length_label_text (GTK_LABEL (priv->exif_focal_label), exif_data);
 
-	eom_exif_set_label (priv->exif_flash_label,
-			    exif_data, EXIF_TAG_FLASH);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_flash_label),
+				      exif_data, EXIF_TAG_FLASH);
 
-	eom_exif_set_label (priv->exif_iso_label,
-			    exif_data, EXIF_TAG_ISO_SPEED_RATINGS);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_iso_label),
+				      exif_data, EXIF_TAG_ISO_SPEED_RATINGS);
 
 
-	eom_exif_set_label (priv->exif_metering_label,
-			    exif_data, EXIF_TAG_METERING_MODE);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_metering_label),
+				      exif_data, EXIF_TAG_METERING_MODE);
 
-	eom_exif_set_label (priv->exif_model_label,
-			    exif_data, EXIF_TAG_MODEL);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_model_label),
+				      exif_data, EXIF_TAG_MODEL);
 
-	eom_exif_set_label (priv->exif_date_label,
-			    exif_data, EXIF_TAG_DATE_TIME_ORIGINAL);
+	eom_exif_util_set_label_text (GTK_LABEL (priv->exif_date_label),
+				      exif_data, EXIF_TAG_DATE_TIME_ORIGINAL);
 
-	eom_exif_details_update (EOM_EXIF_DETAILS (priv->exif_details),
+	eom_metadata_details_update (EOM_METADATA_DETAILS (priv->metadata_details),
 				 exif_data);
 
 	/* exif_data_unref can handle NULL-values */
@@ -434,7 +392,7 @@ pd_update_metadata_tab (EomPropertiesDialog *prop_dlg,
 				   "rights",
 				   priv->xmp_rights_label);
 
-		eom_exif_details_xmp_update (EOM_EXIF_DETAILS (priv->exif_details), xmp_data);
+		eom_metadata_details_xmp_update (EOM_METADATA_DETAILS (priv->metadata_details), xmp_data);
 
 		xmp_free (xmp_data);
 	} else {
@@ -483,10 +441,19 @@ pd_exif_details_activated_cb (GtkExpander *expander,
 #endif
 
 static void
-pd_close_button_clicked_cb (GtkButton *button,
-			    gpointer   user_data)
+pd_folder_button_clicked_cb (GtkButton *button, gpointer data)
 {
-	eom_dialog_hide (EOM_DIALOG (user_data));
+	EomPropertiesDialogPrivate *priv = EOM_PROPERTIES_DIALOG (data)->priv;
+	GtkWindow *window;
+	guint32 timestamp;
+
+	if (!priv->folder_button_uri)
+		return;
+	
+	timestamp = gtk_get_current_event_time ();
+
+	window = GTK_WINDOW (data);
+	gtk_show_uri_on_window (window, priv->folder_button_uri, timestamp, NULL);
 }
 
 static gboolean
@@ -495,25 +462,12 @@ eom_properties_dialog_page_switch (GtkNotebook     *notebook,
 				   guint            page_index,
 				   EomPropertiesDialog *prop_dlg)
 {
-
 	if (prop_dlg->priv->update_page)
 		prop_dlg->priv->current_page = page_index;
 
 	return TRUE;
 }
 
-static gint
-eom_properties_dialog_delete (GtkWidget   *widget,
-			      GdkEventAny *event,
-			      gpointer     user_data)
-{
-	g_return_val_if_fail (EOM_IS_PROPERTIES_DIALOG (user_data), FALSE);
-
-	eom_dialog_hide (EOM_DIALOG (user_data));
-
-	return TRUE;
-}
-
 void
 eom_properties_dialog_set_netbook_mode (EomPropertiesDialog *dlg,
 					gboolean enable)
@@ -537,17 +491,17 @@ eom_properties_dialog_set_netbook_mode (EomPropertiesDialog *dlg,
 		gtk_container_add (GTK_CONTAINER (priv->metadata_details_box), priv->metadata_details_sw);
 		g_object_unref (priv->metadata_details_sw);
 		// Only show details box if metadata is being displayed
-		if (gtk_widget_get_visible (priv->exif_box))
+		if (gtk_widget_get_visible (priv->metadata_box))
 			gtk_widget_show_all (priv->metadata_details_box);
 
-		gtk_widget_hide (priv->exif_details_expander);
+		gtk_widget_hide (priv->metadata_details_expander);
 	} else {
 		g_object_ref (priv->metadata_details_sw);
 		gtk_container_remove (GTK_CONTAINER (gtk_widget_get_parent (priv->metadata_details_sw)),
 				      priv->metadata_details_sw);
-		gtk_container_add (GTK_CONTAINER (priv->exif_details_expander), priv->metadata_details_sw);
+		gtk_container_add (GTK_CONTAINER (priv->metadata_details_expander), priv->metadata_details_sw);
 		g_object_unref (priv->metadata_details_sw);
-		gtk_widget_show_all (priv->exif_details_expander);
+		gtk_widget_show_all (priv->metadata_details_expander);
 
 		if (gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook)) == EOM_PROPERTIES_DIALOG_PAGE_DETAILS)
 			gtk_notebook_prev_page (GTK_NOTEBOOK (priv->notebook));
@@ -619,13 +573,16 @@ eom_properties_dialog_dispose (GObject *object)
 		priv->thumbview = NULL;
 	}
 
+	g_free (priv->folder_button_uri);
+	priv->folder_button_uri = NULL;
+
 	G_OBJECT_CLASS (eom_properties_dialog_parent_class)->dispose (object);
 }
 
 static void
-eom_properties_dialog_class_init (EomPropertiesDialogClass *class)
+eom_properties_dialog_class_init (EomPropertiesDialogClass *klass)
 {
-	GObjectClass *g_object_class = (GObjectClass *) class;
+	GObjectClass *g_object_class = (GObjectClass *) klass;
 
 	g_object_class->dispose = eom_properties_dialog_dispose;
 	g_object_class->set_property = eom_properties_dialog_set_property;
@@ -650,88 +607,143 @@ eom_properties_dialog_class_init (EomPropertiesDialogClass *class)
 							      G_PARAM_READWRITE |
 							      G_PARAM_STATIC_STRINGS));
 
-	g_type_class_add_private (g_object_class, sizeof (EomPropertiesDialogPrivate));
+	GtkWidgetClass *wklass = (GtkWidgetClass*) klass;
+
+	gtk_widget_class_set_template_from_resource (wklass,
+	                                             "/org/mate/eom/ui/eom-image-properties-dialog.ui");
+
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     notebook);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     previous_button);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     next_button);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     close_button);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     thumbnail_image);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     general_box);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     name_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     width_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     height_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     type_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     bytes_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     folder_button);
+
+#if HAVE_EXIF
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_aperture_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_exposure_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_focal_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_flash_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_iso_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_metering_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_model_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     exif_date_label);
+#endif
+#if HAVE_EXEMPI
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_location_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_description_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_keywords_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_creator_label);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_rights_label);
+#else
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_box);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     xmp_box_label);
+#endif
+#ifdef HAVE_METADATA
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     metadata_box);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     metadata_details_expander);
+	gtk_widget_class_bind_template_child_private(wklass,
+						     EomPropertiesDialog,
+						     metadata_details_box);
+
+	gtk_widget_class_bind_template_callback(wklass,
+						pd_exif_details_activated_cb);
+#endif
+	gtk_widget_class_bind_template_callback(wklass,
+						eom_properties_dialog_page_switch);
+	gtk_widget_class_bind_template_callback(wklass,
+						pd_folder_button_clicked_cb);
 }
 
 static void
 eom_properties_dialog_init (EomPropertiesDialog *prop_dlg)
 {
 	EomPropertiesDialogPrivate *priv;
-	GtkWidget *dlg;
-#ifndef HAVE_EXEMPI
-	GtkWidget *xmp_box, *xmp_box_label;
-#endif
 #if HAVE_METADATA
 	GtkWidget *sw;
 #endif
 
-	prop_dlg->priv = EOM_PROPERTIES_DIALOG_GET_PRIVATE (prop_dlg);
+	prop_dlg->priv = eom_properties_dialog_get_instance_private (prop_dlg);
 
 	priv = prop_dlg->priv;
 
 	priv->update_page = FALSE;
 
-	eom_dialog_construct (EOM_DIALOG (prop_dlg),
-			      "eom-image-properties-dialog.ui",
-			      "eom_image_properties_dialog");
+	gtk_widget_init_template (GTK_WIDGET (prop_dlg));
 
-	eom_dialog_get_controls (EOM_DIALOG (prop_dlg),
-			         "eom_image_properties_dialog", &dlg,
-			         "notebook", &priv->notebook,
-			         "previous_button", &priv->previous_button,
-			         "next_button", &priv->next_button,
-			         "close_button", &priv->close_button,
-			         "thumbnail_image", &priv->thumbnail_image,
-			         "general_box", &priv->general_box,
-			         "name_label", &priv->name_label,
-			         "width_label", &priv->width_label,
-			         "height_label", &priv->height_label,
-			         "type_label", &priv->type_label,
-			         "bytes_label", &priv->bytes_label,
-			         "location_label", &priv->location_label,
-			         "created_label", &priv->created_label,
-			         "modified_label", &priv->modified_label,
-#ifdef HAVE_EXIF
-			         "exif_aperture_label", &priv->exif_aperture_label,
-			         "exif_exposure_label", &priv->exif_exposure_label,
-			         "exif_focal_label", &priv->exif_focal_label,
-			         "exif_flash_label", &priv->exif_flash_label,
-			         "exif_iso_label", &priv->exif_iso_label,
-			         "exif_metering_label", &priv->exif_metering_label,
-			         "exif_model_label", &priv->exif_model_label,
-			         "exif_date_label", &priv->exif_date_label,
-#endif
-#ifdef HAVE_EXEMPI
-				 "xmp_location_label", &priv->xmp_location_label,
-				 "xmp_description_label", &priv->xmp_description_label,
-				 "xmp_keywords_label", &priv->xmp_keywords_label,
-				 "xmp_creator_label", &priv->xmp_creator_label,
-				 "xmp_rights_label", &priv->xmp_rights_label,
-#else
-				 "xmp_box", &xmp_box,
-				 "xmp_box_label", &xmp_box_label,
-#endif
-#ifdef HAVE_METADATA
-			         "exif_box", &priv->exif_box,
-				 "exif_details_expander", &priv->exif_details_expander,
-				 "metadata_details_box", &priv->metadata_details_box,
-#endif
-			         NULL);
+	g_signal_connect (prop_dlg,
+	                  "delete-event",
+	                 G_CALLBACK (gtk_widget_hide_on_delete),
+	                 prop_dlg);
 
-	g_signal_connect (dlg,
-			  "delete-event",
-			  G_CALLBACK (eom_properties_dialog_delete),
-			  prop_dlg);
-
-	g_signal_connect (priv->notebook,
-			  "switch-page",
-			  G_CALLBACK (eom_properties_dialog_page_switch),
-			  prop_dlg);
-
-	g_signal_connect (priv->close_button,
-			  "clicked",
-			  G_CALLBACK (pd_close_button_clicked_cb),
-			  prop_dlg);
+	g_signal_connect_swapped (priv->close_button,
+	                          "clicked",
+	                          G_CALLBACK (gtk_widget_hide_on_delete),
+	                          prop_dlg);
 
 	gtk_widget_set_size_request (priv->thumbnail_image, 100, 100);
 
@@ -745,33 +757,28 @@ eom_properties_dialog_init (EomPropertiesDialog *prop_dlg)
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 
-	priv->exif_details = eom_exif_details_new ();
-	gtk_widget_set_size_request (priv->exif_details, -1, 170);
+	priv->metadata_details = eom_metadata_details_new ();
+	gtk_widget_set_size_request (priv->metadata_details, -1, 170);
 	gtk_container_set_border_width (GTK_CONTAINER (sw), 6);
-	gtk_widget_set_vexpand (priv->exif_details, TRUE);
+	gtk_widget_set_vexpand (priv->metadata_details, TRUE);
 
-	gtk_container_add (GTK_CONTAINER (sw), priv->exif_details);
+	gtk_container_add (GTK_CONTAINER (sw), priv->metadata_details);
 	gtk_widget_show_all (sw);
 
 	priv->metadata_details_sw = sw;
 
 	if (priv->netbook_mode) {
-		gtk_widget_hide (priv->exif_details_expander);
+		gtk_widget_hide (priv->metadata_details_expander);
 		gtk_box_pack_start (GTK_BOX (priv->metadata_details_box),
 				    sw, TRUE, TRUE, 6);
 	} else {
-		gtk_container_add (GTK_CONTAINER (priv->exif_details_expander),
+		gtk_container_add (GTK_CONTAINER (priv->metadata_details_expander),
 				   sw);
 	}
 
-	g_signal_connect_after (G_OBJECT (priv->exif_details_expander),
-			        "notify::expanded",
-			  	G_CALLBACK (pd_exif_details_activated_cb),
-			  	dlg);
-
 #ifndef HAVE_EXEMPI
-	gtk_widget_hide (xmp_box);
-	gtk_widget_hide (xmp_box_label);
+	gtk_widget_hide (priv->xmp_box);
+	gtk_widget_hide (priv->xmp_box_label);
 #endif
 
 #else
@@ -796,7 +803,7 @@ eom_properties_dialog_init (EomPropertiesDialog *prop_dlg)
  * Returns: (transfer full) (type EomPropertiesDialog): a new #EomPropertiesDialog
  **/
 
-GObject *
+GtkWidget *
 eom_properties_dialog_new (GtkWindow    *parent,
 			   EomThumbView *thumbview,
 			   GtkAction    *next_image_action,
@@ -810,15 +817,18 @@ eom_properties_dialog_new (GtkWindow    *parent,
 	g_return_val_if_fail (GTK_IS_ACTION (previous_image_action), NULL);
 
 	prop_dlg = g_object_new (EOM_TYPE_PROPERTIES_DIALOG,
-				 "parent-window", parent,
-			     	 "thumbview", thumbview,
-			     	 NULL);
+	                         "thumbview", thumbview,
+	                         NULL);
+
+	if (parent) {
+		gtk_window_set_transient_for (GTK_WINDOW (prop_dlg), parent);
+	}
 
 	gtk_activatable_set_related_action (GTK_ACTIVATABLE (EOM_PROPERTIES_DIALOG (prop_dlg)->priv->next_button), next_image_action);
 
 	gtk_activatable_set_related_action (GTK_ACTIVATABLE (EOM_PROPERTIES_DIALOG (prop_dlg)->priv->previous_button), previous_image_action);
 
-	return prop_dlg;
+	return GTK_WIDGET (prop_dlg);
 }
 
 void
