@@ -73,6 +73,7 @@ enum {
 	PROP_ANTIALIAS_IN,
 	PROP_ANTIALIAS_OUT,
 	PROP_BACKGROUND_COLOR,
+	PROP_IMAGE,
 	PROP_SCROLLWHEEL_ZOOM,
 	PROP_TRANSP_COLOR,
 	PROP_TRANSPARENCY_STYLE,
@@ -164,12 +165,9 @@ static void view_on_drag_data_get_cb (GtkWidget *widget,
 				      GtkSelectionData *data, guint info,
 				      guint time, gpointer user_data);
 
-#define EOM_SCROLL_VIEW_GET_PRIVATE(object) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((object), EOM_TYPE_SCROLL_VIEW, EomScrollViewPrivate))
-
 static gboolean _eom_gdk_rgba_equal0 (const GdkRGBA *a, const GdkRGBA *b);
 
-G_DEFINE_TYPE (EomScrollView, eom_scroll_view, GTK_TYPE_GRID)
+G_DEFINE_TYPE_WITH_PRIVATE (EomScrollView, eom_scroll_view, GTK_TYPE_GRID)
 
 /*===================================
     widget size changing handler &
@@ -384,7 +382,7 @@ eom_scroll_view_set_cursor (EomScrollView *view, EomScrollViewCursor new_cursor)
 	if (cursor) {
 		gdk_window_set_cursor (gtk_widget_get_window (widget), cursor);
 		g_object_unref (cursor);
-		gdk_flush();
+		gdk_display_flush (display);
 	}
 }
 
@@ -611,10 +609,7 @@ scroll_to (EomScrollView *view, int x, int y, gboolean change_adjustments)
 
 	window = gtk_widget_get_window (GTK_WIDGET (priv->display));
 
-	/* Scroll the window area and process exposure synchronously. */
-
 	gdk_window_scroll (window, -xofs, -yofs);
-	gdk_window_process_updates (window, TRUE);
 
  out:
 	if (!change_adjustments)
@@ -1730,6 +1725,31 @@ eom_scroll_view_set_image (EomScrollView *view, EomImage *image)
 	}
 
 	priv->image = image;
+
+	g_object_notify (G_OBJECT (view), "image");
+}
+
+/**
+ * eom_scroll_view_get_image:
+ * @view: An #EomScrollView.
+ *
+ * Gets the the currently displayed #EomImage.
+ *
+ * Returns: (transfer full): An #EomImage.
+ **/
+EomImage*
+eom_scroll_view_get_image (EomScrollView *view)
+{
+	EomImage *img;
+
+	g_return_val_if_fail (EOM_IS_SCROLL_VIEW (view), NULL);
+
+	img = view->priv->image;
+
+	if (img != NULL)
+		g_object_ref (img);
+
+	return img;
 }
 
 gboolean
@@ -1789,7 +1809,7 @@ eom_scroll_view_init (EomScrollView *view)
 	GSettings *settings;
 	EomScrollViewPrivate *priv;
 
-	priv = view->priv = EOM_SCROLL_VIEW_GET_PRIVATE (view);
+	priv = view->priv = eom_scroll_view_get_instance_private (view);
 	settings = g_settings_new (EOM_CONF_VIEW);
 
 	priv->zoom = 1.0;
@@ -1859,7 +1879,8 @@ eom_scroll_view_init (EomScrollView *view)
 
 	gtk_drag_source_set (priv->display, GDK_BUTTON1_MASK,
 			     target_table, G_N_ELEMENTS (target_table),
-			     GDK_ACTION_COPY);
+			     GDK_ACTION_COPY | GDK_ACTION_MOVE |
+			     GDK_ACTION_LINK | GDK_ACTION_ASK);
 	g_signal_connect (G_OBJECT (priv->display), "drag-data-get",
 			  G_CALLBACK (view_on_drag_data_get_cb), view);
 	g_signal_connect (G_OBJECT (priv->display), "drag-begin",
@@ -1980,6 +2001,9 @@ eom_scroll_view_get_property (GObject *object, guint property_id,
 	case PROP_ZOOM_MULTIPLIER:
 		g_value_set_double (value, priv->zoom_multiplier);
 		break;
+	case PROP_IMAGE:
+		g_value_set_object (value, priv->image);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 	}
@@ -2023,6 +2047,9 @@ eom_scroll_view_set_property (GObject *object, guint property_id,
 	case PROP_ZOOM_MULTIPLIER:
 		eom_scroll_view_set_zoom_multiplier (view, g_value_get_double (value));
 		break;
+	case PROP_IMAGE:
+		eom_scroll_view_set_image (view, g_value_get_object (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 	}
@@ -2093,6 +2120,16 @@ eom_scroll_view_class_init (EomScrollViewClass *klass)
 		g_param_spec_boolean ("scrollwheel-zoom", NULL, NULL, TRUE,
 		G_PARAM_READWRITE | G_PARAM_STATIC_NAME));
 
+	/**
+	 * EomScrollView:image:
+	 *
+	 * This is the currently display #EomImage.
+	 */
+	g_object_class_install_property (
+		gobject_class, PROP_IMAGE,
+		g_param_spec_object ("image", NULL, NULL, EOM_TYPE_IMAGE,
+				     G_PARAM_READWRITE | G_PARAM_STATIC_NAME));
+
 	/**
 	 * EomScrollView:transparency-color:
 	 *
@@ -2128,8 +2165,6 @@ eom_scroll_view_class_init (EomScrollViewClass *klass)
 			      G_TYPE_DOUBLE);
 
 	widget_class->size_allocate = eom_scroll_view_size_allocate;
-
-	g_type_class_add_private (klass, sizeof (EomScrollViewPrivate));
 }
 
 static void
